@@ -11,18 +11,20 @@ class k037122_device : public device_t,
 						public device_gfx_interface
 {
 public:
+	static constexpr feature_type imperfect_features() { return feature::GRAPHICS; } // unimplemented tilemap ROZ, scroll registers
+
 	k037122_device(const machine_config &mconfig, const char *tag, device_t *owner, uint32_t clock);
 
 	// configuration
 	void set_gfx_index(int index) { m_gfx_index = index; }
 
 	void tile_draw( screen_device &screen, bitmap_rgb32 &bitmap, const rectangle &cliprect );
-	DECLARE_READ32_MEMBER( sram_r );
-	DECLARE_WRITE32_MEMBER( sram_w );
-	DECLARE_READ32_MEMBER( char_r );
-	DECLARE_WRITE32_MEMBER( char_w );
-	DECLARE_READ32_MEMBER( reg_r );
-	DECLARE_WRITE32_MEMBER( reg_w );
+	uint32_t sram_r(offs_t offset);
+	void sram_w(offs_t offset, uint32_t data, uint32_t mem_mask = ~0);
+	uint32_t char_r(offs_t offset);
+	void char_w(offs_t offset, uint32_t data, uint32_t mem_mask = ~0);
+	uint32_t reg_r(offs_t offset);
+	void reg_w(offs_t offset, uint32_t data, uint32_t mem_mask = ~0);
 
 protected:
 	// device-level overrides
